#!/usr/local/bin/perl
#
#   pwrap - Pwrap Wrap Refereces and Anchors via Plain2
#           by k-chine@is.aist-nara.ac.jp, 1995
#
#	pwrap_subst.pl - substution reference and anchors
#
#   $Id: pwrap_subst.pl,v 1.2 1995/05/19 14:07:38 k-chinen Exp k-chinen $
#
#   You can use, copy, modify, distribute this software freely,
#   but ABSOLUTELY NO WARANTY.
#
# NOTE:
#   This is written by ASCII and Japanese (EUC). And support only ASCII
#	japanese TeX.
#
#   Enjoy.
#

require 'getopts.pl';

&Getopts('htf');


#
# Set Globals
#

$have_abstract = 0;
$section = 0;
$dscale = $opt_t ? 0.7 : 1.0;
$figdir = $opt_f ? $opt_f : "fig";


#
# Show usage
#
if($opt_h) {
    print <<EOF;
pwrap - Pwrap Wrap Referece and Article via Plain2
        by k-chinen\@is.aist-nara.ac.jp

usage: $0 [options] file [files]

option: -h          help
        -t          twocolumn
        -f dir      figure directory

example:
        %
EOF

}



sub begin_abstract {
    print "%%%%% ABSTRACT\n";
    print "\\begin{abstract}\n";
}

sub end_abstract {
    print "\\end{abstract}\n\n";
}



sub print_figure_box {
    $pscale=$scale*$dscale;
    print <<EOF;
% Figure
%
% \\vspace{5mm}%
  \\typeout{PWRAP Warning: fig-'$name' was not found in dir-'$figdir'}%
  \\begin{figure}[htbp]
  \\begin{center}
  \\thicklines%
  \\fbox{%
      \\vbox to 2cm{%
        \\vfill%
        \\hbox to 5cm {%
          \\space\\hfill\\space{}$name\\space{}$pscale\\hfill\\space%
        }%
        \\vfill%
      }%
    }%
  \\caption{$note}\\label{fig:$name}
  \\end{center}%
  \\end{figure}%
% \\vspace{5mm}
EOF
}

sub print_figure {
    $pscale=$scale*$dscale;
    print <<EOF;
% Figure
% \\vspace{5mm}%
  \\begin{figure}[htbp]
  \\begin{center}
  \\epsfile{file=$figdir/$name.eps,scale=$pscale}
  \\end{center}%
  \\vspace{-7mm}
% \\caption{$note --- $name $scale}\\label{fig:$name}
  \\caption{$note}\\label{fig:$name}
  \\end{figure}%
% \\vspace{5mm}
EOF
}


while(<>) {
    s/\@\@fig\(([^)]*)\)/~\\ref{fig:\1}/g;
    s/\@\@bib\((\w+)\)/\\cite{\1}/g;

    if(/^\\#/) {
	chop;
        if(/^\\#[Aa]bstract/) {
            print "\\centerline{\\large\\bf Abstract}\\noindent\n";
        }
        elsif (/^\\#[Ff]igure/) {
#           if (/^\\#[Ff]igure,([^,]+),([\d\.]+),'([^']+)'/) {
            if (/^\\#[Ff]igure,([^,]+),([\d\.]+),([^']+)/) {
                $name=$1; $scale=$2; $note=$3;
#               ($dummy, $name, $scale, $note) = split(/,/,$_);

                # if EPS-file is exist, include it.
                if ( -f "$figdir/$name.eps") {
                    &print_figure();
                }
                else {
                    &print_figure_box();
                }
            }
            else {
                print "%%%%% Figure ERROR\n";
            }

        }
        elsif (/^\\#[Rr]eferences/) {
            print "\\section*{ͻ}\n";
#           print "\\input{bib}\n";
        }
        elsif (/^\\#[Aa]cknowledgment/) {
            print "\\section*{ռ}\n";
        }
        else {
            print "\\par\n\\noindent{\\bf--- Unsupport Commands ---}\n";
        }
    }
    elsif(/^\\setcounter{section}{-1}/) {
        print "%%%%% $_";
        $have_abstract = 1;
    }
    elsif(/^\\section{/) {
        if($have_abstract && $section eq 0) {
            &begin_abstract();
        }
        else {
            if($section eq 1) {
                &end_abstract();
            }
            print "%%%%% SECTION $section\n";
            print $_;
        }
        $section++;
    }
    else {
        print "$_";
    }
}


